<?php

/**
 * @file
 * A mock OAuth 2.0 client for use with tests.
 */

/**
 * Implements a test OAuth 2.0 client.
 */
class BlizzardApiLoginTestClient extends BlizzardApiLoginClient {
  const AUTHORIZE_PATH = 'oauth/authorize';
  const TOKEN_PATH = 'oauth/token';
  
  protected $token;
  
  /**
   * Constructs a BlizzardApiLoginTestClient object.
   *
   * @param string $region
   *   A supported Battle.net login region.
   * @param array $scopes
   *   (optional) Not used.
   */
  public function __construct($region, $scopes = array()) {
    parent::__construct($region, $scopes);
    
    $this->client = new stdClass();
    $this->client->client_id = variable_get('blizzardapi_public_key', '');
    $this->client->client_secret = variable_get('blizzardapi_private_key', '');
  }
  
  /**
   * Returns a sample token. Does not authenticate anything.
   */
  public function authenticate($code) {
    // The test module just returns a sample token, no POST data is required.
    $url = url(self::TOKEN_PATH, array('absolute' => TRUE));
    $context = stream_context_create(array('ssl' => array('allow_self_signed' => TRUE)));
    $response = drupal_http_request($url, array('context' => $context));
    $this->token = json_decode($response->data, TRUE);
    
    // Simulate multiple accounts.
    if ($this->region == BlizzardApiLoginClient::REGION_EU) {
      $this->token['accountId'] = 456;
    }
    else if ($this->region == BlizzardApiLoginClient::REGION_KR) {
      $this->token['accountId'] = 789;
    }
  }
  
  /**
   * {@inheritdoc}
   */
  public function getAccessToken() {
    return $this->token;
  }
  
  /**
   * {@inheritdoc}
   */
  public function getAccessTokenScopes() {
    return $this->token['scope'];
  }
  
  /**
   * Returns a link to the test login page.
   */
  public function getAuthorizeUrl($state = '') {
    $query = array(
      'client_id' => $this->client->client_id,
      'redirect_uri' => $this->redirectUrl,
      'response_type' => 'code'
    );
    
    if (!empty($this->scopes)) {
      $query['scope'] = implode(' ', $this->scopes);
    }
    if (!empty($state)) {
      $query['state'] = $state;
    }
    
    return url(self::AUTHORIZE_PATH, array('query' => $query, 'absolute' => TRUE));
  }
  
  /**
   * {@inheritdoc}
   */
  public function getClient() {
    return $this->client;
  }
}

/**
 * Is not an implementation of BlizzardApiLoginClient.
 */
class BlizzardApiLoginInvalidClient {
  public function __construct($region, $scopes = array()) {}
}
